==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkResliceCursorWidget.java <==
// java wrapper for vtkResliceCursorWidget object
//

package vtk;
import vtk.*;

public class vtkResliceCursorWidget extends vtkAbstractWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkResliceCursorRepresentation id0);
  public void SetRepresentation(vtkResliceCursorRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetResliceCursorRepresentation_3();
  public vtkResliceCursorRepresentation GetResliceCursorRepresentation() {
    long temp = GetResliceCursorRepresentation_3();

    if (temp == 0) return null;
    return (vtkResliceCursorRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_4();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_4(); }

  private native void SetEnabled_5(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_5(id0); }

  private native void SetManageWindowLevel_6(int id0);
  public void SetManageWindowLevel(int id0)
    { SetManageWindowLevel_6(id0); }

  private native int GetManageWindowLevel_7();
  public int GetManageWindowLevel()
    { return GetManageWindowLevel_7(); }

  private native void ManageWindowLevelOn_8();
  public void ManageWindowLevelOn()
    { ManageWindowLevelOn_8(); }

  private native void ManageWindowLevelOff_9();
  public void ManageWindowLevelOff()
    { ManageWindowLevelOff_9(); }

  private native void ResetResliceCursor_10();
  public void ResetResliceCursor()
    { ResetResliceCursor_10(); }

  public vtkResliceCursorWidget() { super(); }

  public vtkResliceCursorWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv7h.pkg.tar.xz: vtk/vtkResliceCursorWidget.java <==
// java wrapper for vtkResliceCursorWidget object
//

package vtk;
import vtk.*;

public class vtkResliceCursorWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRepresentation_2(vtkResliceCursorRepresentation id0);
  public void SetRepresentation(vtkResliceCursorRepresentation id0)
    { SetRepresentation_2(id0); }

  private native long GetResliceCursorRepresentation_3();
  public vtkResliceCursorRepresentation GetResliceCursorRepresentation() {
    long temp = GetResliceCursorRepresentation_3();

    if (temp == 0) return null;
    return (vtkResliceCursorRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_4();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_4(); }

  private native void SetEnabled_5(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_5(id0); }

  private native void SetManageWindowLevel_6(int id0);
  public void SetManageWindowLevel(int id0)
    { SetManageWindowLevel_6(id0); }

  private native int GetManageWindowLevel_7();
  public int GetManageWindowLevel()
    { return GetManageWindowLevel_7(); }

  private native void ManageWindowLevelOn_8();
  public void ManageWindowLevelOn()
    { ManageWindowLevelOn_8(); }

  private native void ManageWindowLevelOff_9();
  public void ManageWindowLevelOff()
    { ManageWindowLevelOff_9(); }

  private native void ResetResliceCursor_10();
  public void ResetResliceCursor()
    { ResetResliceCursor_10(); }

  public vtkResliceCursorWidget() { super(); }

  public vtkResliceCursorWidget(long id) { super(id); }
  public native long   VTKInit();

}
